package com.ruoyi.system.service.fgw;

import com.ruoyi.system.domain.fgw.FgwJzqk;

import java.util.List;

/**
 * 发改委_进展情况Service接口
 * 
 * @author boman
 * @date 2023-03-22
 */
public interface IFgwJzqkService 
{
    /**
     * 查询发改委_进展情况
     * 
     * @param id 发改委_进展情况主键
     * @return 发改委_进展情况
     */
    public FgwJzqk selectFgwJzqkById(Long id);

    /**
     * 查询发改委_进展情况列表
     * 
     * @param fgwJzqk 发改委_进展情况
     * @return 发改委_进展情况集合
     */
    public List<FgwJzqk> selectFgwJzqkList(FgwJzqk fgwJzqk);

    /**
     * 统计本周汇报进度
     * @param fgwJzqk
     * @return
     */
    public List<FgwJzqk> selectFgwJzqkTj(FgwJzqk fgwJzqk);

    /**
     * 新增发改委_进展情况
     * 
     * @param fgwJzqk 发改委_进展情况
     * @return 结果
     */
    public int insertFgwJzqk(FgwJzqk fgwJzqk);

    /**
     * 修改发改委_进展情况
     * 
     * @param fgwJzqk 发改委_进展情况
     * @return 结果
     */
    public int updateFgwJzqk(FgwJzqk fgwJzqk);

    /**
     * 批量删除发改委_进展情况
     * 
     * @param ids 需要删除的发改委_进展情况主键集合
     * @return 结果
     */
    public int deleteFgwJzqkByIds(Long[] ids);

    /**
     * 删除发改委_进展情况信息
     * 
     * @param id 发改委_进展情况主键
     * @return 结果
     */
    public int deleteFgwJzqkById(Long id);
}
